Python bindings for Maude
=========================

Python bindings for [Maude](https://maude.cs.illinois.edu) using [SWIG](https://www.swig.org).

The `maude` package allows manipulating terms, modules, and other entities of the Maude specification language as Python objects, whose methods expose the operations available as commands in the Maude interpreter.

See the [repository](https://github.com/fadoss/maude-bindings) for additional information, documentation, and examples.
